pub struct DevConfig {
pub working_directory: PathBuf,
pub rust: CommandSpec,
pub vite: CommandSpec,
pub client_build: CommandSpec,
pub renderer_build: CommandSpec,
pub build_frontend: bool,
pub watch_rust: bool,
}Fields
working_directory: PathBufrust: CommandSpecvite: CommandSpecclient_build: CommandSpecrenderer_build: CommandSpecbuild_frontend: boolBuild browser and renderer bundles before each backend restart.
watch_rust: boolWhen true (default), watch backend and frontend sources and restart cargo run on change.
Implementations
Sourceimpl DevConfig
impl DevConfig
pub fn working_directory(self, directory: impl Into<PathBuf>) -> Self
pub fn rust(self, command: CommandSpec) -> Self
pub fn vite(self, command: CommandSpec) -> Self
pub fn client_build(self, command: CommandSpec) -> Self
pub fn renderer_build(self, command: CommandSpec) -> Self
pub const fn build_frontend(self, enabled: bool) -> Self
pub const fn watch_rust(self, enabled: bool) -> Self